//##generation header##CodeWorker##3.10.4##30may2005 19:16:43##
//##header start##
//Popeye's Village
//Gozo and Comino
//##header end##
package tiny;

public class SolarSystem {
	// attributes:
	private  _planets = null;

	//constructor:
	public SolarSystem() {
	}

	// accessors:
	public  getPLANETS() { return _planets; }
	public void setPLANETS( planets) { _planets = planets; }
//##protect##"Methods"
//##protect##"Methods"
}
